# 开始吧！

欢迎使用Rapunzel，一个针对Python和R的现代开发环境。以下为您列出了一些键盘快捷键。


## 使用项目文件夹和文件

- [`Ctrl+Shift+O`: 打开项目文件夹](opensesame://event.rapunzel_welcome_open_folders)
- [`Ctrl+O`: 从项目文件夹中打开文件](opensesame://event.rapunzel_welcome_open_files)
- [`Ctrl+N`: 新建空白文档](opensesame://event.ide_new_file)


## 快捷功能

- [`Ctrl+Shift+P`: 激活任务选项板](opensesame://event.command_palette_activate)
- `Ctrl+R`: 跳转到某项功能或类别


## 运行代码

- `F5`: 运行项目或文件
- `F9`: 运行选项，单元格或当前行
